#
# spec file for package nextcloud-desktop
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define soname  libnextcloudsync
%define sover   0
Name:           nextcloud-desktop
Version:        2.6.4
Release:        lp152.1.2
Summary:        Nextcloud desktop synchronisation client
License:        GPL-2.0-or-later AND LGPL-3.0-or-later
URL:            https://nextcloud.com/
Source:         https://github.com/nextcloud/desktop/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
Source1:        sysctl-sync-inotify.conf
# PATCH-FIX-OPENSUSE nextcloud-desktop-fix-rpath.patch sor.alexei@meowr.ru -- Fix RPATH.
Patch0:         nextcloud-desktop-fix-rpath.patch
# PATCH-FIX-OPENSUSE nextcloud-desktop-remove-datetime.patch sor.alexei@meowr.ru -- Remove __TIME__ and __DATE__.
Patch1:         nextcloud-desktop-remove-datetime.patch
BuildRequires:  AppStream
BuildRequires:  cmake >= 3.2
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  glibc-devel
BuildRequires:  gobject-introspection-devel
BuildRequires:  hicolor-icon-theme
BuildRequires:  libqt5-linguist-devel
BuildRequires:  pkgconfig
BuildRequires:  qtkeychain-qt5-devel
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(Qt5Concurrent)
BuildRequires:  pkgconfig(Qt5Core)
BuildRequires:  pkgconfig(Qt5DBus)
BuildRequires:  pkgconfig(Qt5Gui)
BuildRequires:  pkgconfig(Qt5Network)
BuildRequires:  pkgconfig(Qt5PrintSupport)
BuildRequires:  pkgconfig(Qt5Sql)
BuildRequires:  pkgconfig(Qt5WebEngineWidgets)
BuildRequires:  pkgconfig(Qt5WebKitWidgets)
BuildRequires:  pkgconfig(Qt5Xml)
BuildRequires:  pkgconfig(dbus-1)
BuildRequires:  pkgconfig(openssl) >= 1.1
BuildRequires:  pkgconfig(sqlite3)
BuildRequires:  pkgconfig(zlib)
Requires:       %{soname}%{sover} = %{version}
Provides:       nextcloud-client = %{version}
Obsoletes:      nextcloud-client < %{version}
Obsoletes:      nextcloud-client-lang < %{version}
%if 0%{?is_opensuse}
BuildRequires:  doxygen
BuildRequires:  kio-devel
BuildRequires:  python3-Sphinx
Suggests:       %{name}-doc = %{version}
%endif

%description
The Nextcloud Desktop Client is a tool to synchronise files from
the Nextcloud Server with your computer.

Nextcloud Desktop enables you to connect to your private
Nextcloud Server. With it you can create directories in your home
directory, and keep the contents of those directories synced with
the server. Simply copy a file into the directory and the desktop
synchronisation client does the rest.

%lang_package

%if 0%{?is_opensuse}
%package doc
Summary:        Documentation for nextcloud-desktop
Provides:       nextcloud-client-doc = %{version}
Obsoletes:      nextcloud-client-doc < %{version}
BuildArch:      noarch

%description doc
The Nextcloud Desktop Client is a tool to synchronise files from
the Nextcloud Server with your computer.

This package contains the documentation.
%endif

%package -n %{soname}%{sover}
Summary:        The Nextcloud synchronisation library

%description -n %{soname}%{sover}
The Nextcloud Desktop Client synchronisation library.

%package -n %{soname}-devel
Summary:        Development files for the Nextcloud synchronisation library
Requires:       %{soname}%{sover} = %{version}

%description -n %{soname}-devel
Development files for the Nextcloud Desktop Client synchronisation
library.

%package -n nautilus-extension-nextcloud
Summary:        Nautilus overlay icons
Requires:       %{name} = %{version}
Requires:       nautilus
Requires:       python3-nautilus
Supplements:    (%{name} and nautilus)
BuildArch:      noarch

%description -n nautilus-extension-nextcloud
This package provides overlay icons to visualise the
synchronisation state in the Nautilus file manager.

%if 0%{?is_opensuse}
%package -n caja-extension-nextcloud
Summary:        Caja overlay icons
Requires:       %{name} = %{version}
Requires:       caja
Requires:       python-caja
Supplements:    (%{name} and caja)
BuildArch:      noarch

%description -n caja-extension-nextcloud
This package provides overlay icons to visualise the
synchronisation state in the Caja file manager.

%package -n nemo-extension-nextcloud
Summary:        Nemo overlay icons
Requires:       %{name} = %{version}
Requires:       nemo
Requires:       python-nemo
Supplements:    (%{name} and nemo)
BuildArch:      noarch

%description -n nemo-extension-nextcloud
This package provides overlay icons to visualise the
synchronisation state in the Nemo file manager.

%package -n %{name}-dolphin
Summary:        Dolphin overlay icons
Requires:       %{name} = %{version}
Requires:       dolphin
Supplements:    (%{name} and dolphin)

%description -n %{name}-dolphin
This package provides the necessary plugin libraries for the
Dolphin filemanager to display overlay icons.
%endif

%prep
%setup -q -n desktop-%{version}
%patch0 -p1
%patch1 -p1
cp -a %{SOURCE1} sysctl-sync-inotify.conf

%build
%cmake \
%if 0%{?is_opensuse}
  -DWITH_DOC=ON          \
%endif
  -DCMAKE_SKIP_RPATH=OFF
%cmake_build

%install
%cmake_install

%if 0%{?is_opensuse}
mkdir -p %{buildroot}%{_docdir}/%{name}-doc/
mv -f %{buildroot}%{_datadir}/doc/client/nextcloud-client/html/ \
  %{buildroot}%{_docdir}/%{name}-doc/html/
%else
# There's no Caja and Nemo in SLE.
rm -r %{buildroot}%{_datadir}/caja-python/
rm -r %{buildroot}%{_datadir}/nemo-python/
%endif

# Generate bytecode for extensions.
for fm in caja nautilus nemo; do
    if [ -d %{buildroot}%{_datadir}/$fm-python/ ]; then
        %py3_compile %{buildroot}%{_datadir}/$fm-python/extensions/
    fi
done

# ecsos: Comment this out, because it seems to be a security risk.
# See: https://github.com/owncloud/client/issues/4107#issuecomment-240627858
# A workaround for gh#owncloud/client#4107
#install -Dpm 0644 sysctl-sync-inotify.conf \
#  %%{buildroot}%%{_sysconfdir}/sysctl.d/99-%%{name}-sync-inotify.conf

%suse_update_desktop_file nextcloud
%fdupes %{buildroot}%{_datadir}/

%post -n %{soname}%{sover} -p /sbin/ldconfig

%postun -n %{soname}%{sover} -p /sbin/ldconfig

%files
%license COPYING*
%config %{_sysconfdir}/Nextcloud/
#%%config %%{_sysconfdir}/sysctl.d/99-%%{name}-sync-inotify.conf
%{_bindir}/nextcloud*
%dir %{_datadir}/nextcloud/
%{_datadir}/applications/nextcloud.desktop
%dir %{_datadir}/icons/hicolor/1024x1024/
%dir %{_datadir}/icons/hicolor/1024x1024/apps/
%{_datadir}/icons/hicolor/*/apps/Nextcloud*.*

%files lang
%{_datadir}/nextcloud/i18n/

%if 0%{?is_opensuse}
%files doc
%doc %{_docdir}/%{name}-doc/
%endif

%files -n %{soname}%{sover}
%license COPYING*
%{_libdir}/%{soname}.so.*
%dir %{_libdir}/nextcloud/
%{_libdir}/nextcloud/libocsync.so.*

%files -n %{soname}-devel
%{_includedir}/nextcloudsync/
%{_libdir}/%{soname}.so
%{_libdir}/nextcloud/libocsync.so

%files -n nautilus-extension-nextcloud
%dir %{_datadir}/nautilus-python/
%dir %{_datadir}/nautilus-python/extensions/
%dir %{_datadir}/nautilus-python/extensions/__pycache__
%{_datadir}/nautilus-python/extensions/syncstate-Nextcloud.py*
%{_datadir}/nautilus-python/extensions/__pycache__/syncstate-Nextcloud*

%if 0%{?is_opensuse}
%files -n caja-extension-nextcloud
%dir %{_datadir}/caja-python/
%dir %{_datadir}/caja-python/extensions/
%dir %{_datadir}/caja-python/extensions/__pycache__
%{_datadir}/caja-python/extensions/syncstate-Nextcloud.py*
%{_datadir}/caja-python/extensions/__pycache__/*

%files -n nemo-extension-nextcloud
%dir %{_datadir}/nemo-python/
%dir %{_datadir}/nemo-python/extensions/
%dir %{_datadir}/nemo-python/extensions/__pycache__
%{_datadir}/nemo-python/extensions/syncstate-Nextcloud.py*
%{_datadir}/nemo-python/extensions/__pycache__/*

%files dolphin
%{_libdir}/libnextclouddolphinpluginhelper.so
%{_libdir}/qt5/plugins/nextclouddolphinactionplugin.so
%dir %{_libdir}/qt5/plugins/kf5/overlayicon/
%{_libdir}/qt5/plugins/kf5/overlayicon/nextclouddolphinoverlayplugin.so
%{_datadir}/kservices5/nextclouddolphinactionplugin.desktop
%endif

%changelog
* Sun Mar  8 2020 Alexei Sorokin <sor.alexei@meowr.ru>
- Rename nextcloud-client to nextcloud-desktop following upstream.
- Stop redundantly recommending the -lang package.
* Wed Mar  4 2020 ecsos@opensuse.org
- Update to 2.6.4
  * Fix Explorer pinning: Add fallbacks for Shell commands
    (gh#nextcloud/desktop#1599).
  * WebFlowCredentials: Make username comparison case-insensitive
    (gh#nextcloud/desktop#1741).
  * ActivityListModel: Show full date and time as a Tooltip only.
  * Disable HTTP/2 for now due to a Qt bug, allow enabling it via
    an environment variable.
  * Fix Explorer integration re-save and hide option.
  * l10n: Changes to improve source strings.
  * Updater: Add query-parameter "updatesegment" to the update
    check.
* Mon Feb 17 2020 ecsos@opensuse.org
- Update to 2.6.3
  - desktop#1782 Add UserInfo class and fetch quota via API instead
    of PropfindJob
  - desktop#1770 l10n: Changed grammar and triple dots to ellipsis
  - desktop#1767 l10n: Changed spelling of user name to username
  - desktop#1765 Start the client in background if activated
    by D-Bus
  - desktop#1764 Do not install files related to cloud providers
    under Xenial
  - desktop#1763 Make sure that the libcloudprovider integration is
    using a valid D-Bus path
  - desktop#1762 Changed product name to Nextcloud
  - desktop#1760 Update autoupdate.rst
  - desktop#1745 Use system proxy by default if no config file is
    present
  - desktop#1729 Install libcloudproviders files by default on
    debian
  - desktop#1727 Windows 7 is out of support
  - desktop#1721 BugFix: Handle broken shared file error gracefully
  - desktop#1720 Fix Explorer integration on Windows and the crash
    on other systems
  - desktop#1718 Welcome to 2020
  - desktop#1707 Updated year in legalnotice.cpp
  - desktop#1699 apply http2 qt resend patch from owncloud
- Run spec-cleaner.
* Wed Dec 25 2019 ecsos@opensuse.org
- Update to 2.6.2
  - desktop#1456 Revert DEFAULT_REMOTE_POLL_INTERVAL back from 5
    seconds to 30 seconds
  - desktop#1459 Use user-provided username in displayName() -
    Fix #836
  - desktop#1462 Fix typo
  - desktop#1471 Build with libcloudproviders on debian and in the
    AppImage
  - desktop#1487 Fix tests for Windows platform
  - desktop#1523 Merge the list of ignored files/symlinks into one
    Activity notification.
  - desktop#1526 Fix clang's variadic macro warnings
  - desktop#1531 Add libdbus-1-dev to the build dependencies
  - desktop#1593 Compare QDateTime objects more efficient
  - desktop#1611 Improve the translation of "Share via …"
  - desktop#1617 Upgrade for Qt 5.12.5 in docker-ci
  - desktop#1619 Bump Qt 5.12.5 image
  - desktop#1621 Add timestamp to Mac installer code signing
  - desktop#1623 MacOS build: Avoid the Get-Task-Allow Entitlement
    (Notarization)
  - desktop#1629 Build for Debian stable and oldstable
  - desktop#1641 Happy new year
  - desktop#1644 Fall back to old login flow on GS as this is not
    yet ready
  - desktop#1645 [stable-2.6] macOS build: Avoid the Get-Task-Allow
    Entitlement (Notarization)
  - desktop#1646 Fix remote wipe keychain storage (issue #1592)
  - desktop#1647 Fix copyright year in MacOSXBundleInfo.plist.in
    for 2019
  - desktop#1651 Fix macOS GUI (Qt 5.12)
  - desktop#1664 Windows: Workaround for storing >= 4k (4096 bit)
    client-cert SSL keys
* Fri Nov  8 2019 Alexei Sorokin <sor.alexei@meowr.ru>
- Rename 100-nextcloud-client-sync-inotify.conf to
  99-nextcloud-client-sync-inotify.conf (boo#1155457).
* Tue Nov  5 2019 ecsos@opensuse.org
- Update to 2.6.1
  - desktop#1032 Changed max GUI bandwidth limits
  - desktop#1039 Add sync date next to "Synchronized with local
    folder"
  - desktop#1149 Slideshow buttons
  - desktop#1214 Fix qt warning about registering a URL sheme first.
  - desktop#1231 Issue #1216: added sync-exclude entry for emacs
    recovery files
  - desktop#1240 Race condition in the remote size loading logic
  - desktop#1409 Review of msvc/gcc warnings -> code cleanup,
    prevention of implicit casts, variadic macros
  - desktop#1414 Fix double slashes
  - desktop#1420 Fixing E2E CSR transmission failure for new
    connections
  - desktop#1441 Fixed missing 'translatable' exclusions, added
    missing window titles
  - desktop#1461 Checks if exclude file is empty before creating
    the regular expressions.
  - desktop#1465 Add server info to menu
  - desktop#1474 Fixed grammar
  - desktop#1477 Prevent jumping of tray menu
  - desktop#1478 Don't run connection wizard when quitting the
    application
  - desktop#1481 Avoiding copying in range-based loops
  - desktop#1495 Add a 'Content-Length: 0' header to initial POST
    requests
  - desktop#1504 Remote wipe.
  - desktop#1520 Pick from upstream: Update qtmacgoodies for an OSX
    crash fix #6930
  - desktop#1522 * fix for issue no. #1351
  - desktop#1523 Merge the list of ignored files/symlinks into one
    Activity notification.
  - desktop#1527 Update submodules for Qt 5.12.5 (qtmacgoodies)
  - desktop#1554 Fix duplicate items in Apps menu
    (a bug introduced in #1477)
  - desktop#1573 Fix #1182
  - desktop#1579 Fix remote wipe when a proxy is configured.
  - desktop#1580 Fix updater message: Download link instead of
    "use the system's update
* Thu Oct 10 2019 Dominique Leuenberger <dimstar@opensuse.org>
- Do not BuildRequire python: this is python2, but in other places
  we buildrequire python3-Sphinx. This does not really belong
  together.
- Switch the python-nautilus Requires in
  nautilus-extension-nextcloud to be python3-nautilus: the plugin
  supports py3 already, so best to make use of it.
* Fri Sep 27 2019 Mathias Homann <Mathias.Homann@opensuse.org>
- Update to 2.6.0
  * desktop#1222 Reinstate Debian build in the new Drone config
  * desktop#1225 Typo
  * desktop#1256 Marking unused strings as unstranslatable
  * desktop#1275 Fixes #607
  * desktop#1278 Fixes issue #878
  * desktop#1342 Fixes issue #1187
  * desktop#1347 Displays FileIgnored activities with an info icon
  * desktop#1354 Minor text change in the link to help in the tab 'General'.
  * desktop#1359 Update Qt 5.5 compatibility patch for Xenial
  * desktop#1360 Remove Ubuntu Cosmic and add Eoan package
  * desktop#1366 Add proper CA to client side certificate connection
  * desktop#1372 Remove dependency on libgnome-keyring0 on Eoan
  * desktop#1374 Read .sync_exclude.lst in each subdirectory
  * desktop#1376 Updates ChangeLog.
  * desktop#1384 Login flow v2
  * desktop#1389 Adds SSL client cert storage to webflow + Login Flow v2
  * desktop#1394 Windows: Workaround for CredWriteW used by QtKeychain
  * desktop#1399 Integrated registry check on windows when hasDarkSystray is called.
  * desktop#1401 Logo update
  * desktop#1402 Updated .gitignore to integrate unwanted files when working with VSC …
  * desktop#1405 Full-Scaled new logo in Windows 10 start menu tile
  * desktop#1408 Qt5.5 compatiblity patch for login flow V2 + UI improvement (Use newer digest algorithms in TLS error dialog)
  * desktop#1427 Fix for #1382 "linux client crashes for no discernable reason"
  * desktop#1434 UI improvement: Message box: Delete / Keep all files
  * desktop#1443 Improve wording of the context menu in the file manager extension.
  * desktop#1447 Changes wording in the share context menu.
  * Fix White Window issue on Windows by upgrading to Qt 5.12.5
* Mon Jul 22 2019 ecsos@opensuse.org
- Update to 2.5.3
  - desktop#1118 Fix empty file wording in error log (small)
  - desktop#1153 Add Qt-5.12 to CI
  - desktop#1157 Fix a minor typo
  - desktop#1185 Libcloudproviders: Add missing check for Qt5DBus
  - desktop#1186 Fix several memory leaks in cloudproviders and add
    translation support
  - desktop#1191 Share link fixing
  - desktop#1200 New drone config
  - desktop#1201 Uses configuraion to determine if it should show
    empty folder popup.
  - desktop#1212 Simplify cmake command to make copy-pastable
  - desktop#1234 Updated default remote poll to 5 seconds #1115
  - desktop#1239 Fix memory leak with device pointer
  - desktop#1241 Added a nice UI for the E2E-enabled account first
    connect
  - desktop#1245 This should fix issue #1000
  - desktop#1247 Adds parameter to retrieve shares with its
    reshares.
  - desktop#1251 Fixed typo
  - desktop#1253 Fixed typo in "certificate"
  - desktop#1273 WebView: Properly handle usernames with spaces and
    plus signs in it
  - desktop#1301 Add error category for http file lock error status
    423.
  - desktop#1309 Displays the uid_owner of a shared file.
* Tue Apr 30 2019 Bjoern Voigt <bjoernv@arcor.de>
- Update to version 2.5.2
  * desktop#1001 Handle spaces in username properly in login flow
  * desktop#1006 Wizard: show an error message if there is no enough free space in the local folder
  * desktop#1050 Removed whitespace from string
  * desktop#1054 Do not add double slash to login flow url
  * desktop#1057 Fix login flow with system proxy
  * desktop#1060 Start with easier theming
  * desktop#1062 Do not display dismissed notifications
  * desktop#1069 Fixed l18n issue. Added space for separating string
  * desktop#1071 Add invalid certiticate messagebox
  * desktop#1087 Correct app passwords link
  * desktop#1092 Be less verbose with logging
  * desktop#1119 Fix typo in translation string
  * desktop#778 Add a command line option to launch the client in the background
  * desktop#923 Support Ubuntu Disco Dingo
  * desktop#946 Added missing Include
  * desktop#959 Make sure _profile and _page are deleted in the correct order
  * desktop#981 Fix KDEInstallDirs deprecation warnings
  * desktop#993 Removed Stylesheet
- Removed nextcloud-client-fix-qt-5.12.patch
* Tue Jan 15 2019 Alexei Sorokin <sor.alexei@meowr.ru>
- Stop building with libcloudproviders (boo#1118327).
* Mon Jan  7 2019 Alexei Sorokin <sor.alexei@meowr.ru>
- Append to nextcloud-client-fix-qt-5.12.patch a fix for a
  QtWebEngine crash on Qt 5.12 (commit 09b0055, boo#1120310).
* Wed Jan  2 2019 Alexei Sorokin <sor.alexei@meowr.ru>
- Add nextcloud-client-fix-qt-5.12.patch: Fix an error during build
  with Qt 5.12 (commit 1295884).
* Tue Dec  4 2018 Alexei Sorokin <sor.alexei@meowr.ru>
- Update to version 2.5.1:
  * See https://github.com/nextcloud/desktop/compare/v2.5.0...v2.5.1
* Wed Nov 14 2018 sor.alexei@meowr.ru
- Update to version 2.5.0:
  * See https://github.com/nextcloud/desktop/compare/57bc791...v2.5.0
- Remove nextcloud-client-2.3.3-fix-qt-5.11.patch,
  nextcloud-client-fix-caja-nemo-appnames.patch: fixed upstream.
- Rebase nextcloud-client-fix-rpath.patch,
  nextcloud-client-remove-datetime.patch.
- Build with libcloudproviders.
- Drop openSUSE Leap 42.3 and older support.
* Tue Jun 12 2018 sor.alexei@meowr.ru
- Add nextcloud-client-2.3.3-fix-qt-5.11.patch: Fix Qt 5.11+
  compatibility.
* Thu Mar  1 2018 ecsos@opensuse.org
- fix build error for Tumbleweed
* Mon Dec 25 2017 sor.alexei@meowr.ru
- Use a better tarball.
* Tue Dec  5 2017 sor.alexei@meowr.ru
- Update to version 2.3.3:
  * Chunking NG: Don't use old chunking on new DAV endpoint
    (gh#owncloud/client#5855).
  * Selective Synch: Skip excluded directories when reading DB,
    don't let them show errors (gh#owncloud/client#5772).
  * Settings: Make the window bigger so the Qt version is always
    visible (gh#owncloud/client#5760).
  * Share links: Show a warning that public link shares are public
    (gh#owncloud/client#5786).
  * Downloads: Re-trigger directory discovery on HTTP 404
    (gh#owncloud/client#5799).
  * Notifications: Propagate "Dismiss" as DELETE to server
    (gh#owncloud/client#5922).
  * SynchJournalDB: Don't use ._ as a filename pattern if that does
    not work because of SMB storage settings
    (gh#owncloud/client#5844)
  * SynchJournalDB: Log reason for sqlite3 opening errors.
  * Stop maintaining Qt 4 support.
  * New synch state icon design.
  * Add a state-information icon.
  * Update the icon patch.
* Fri Jul 21 2017 ecsos@opensuse.org
- update to 2.3.2
  * Fix more crashes (thanks to everyone submitting to our crash
    reporter!)
  * Improve compatibility with server 10.0 (5691, X-OC-Total-Size)
  * Share dialog: UI improvements, Bring to front on tray click
  * owncloudcmd: Align process return value with sync return value
    (3936)
  * Fix disk free check on Windows when opening the local DB
- insert Requires: %%{soname}%%{sover} = %%{version} because lib
  does not up- or downgrade by up- or downgrade from client itself.
* Wed Jun 14 2017 sor.alexei@meowr.ru
- Only enable documentation for openSUSE Leap 14.3 and newer
  (boo#1044061).
* Thu Mar 23 2017 sor.alexei@meowr.ru
- Update to version 2.3.1 (changes since 2.2.4):
  * Decreased memory usage during synchronisation.
  * Overlay icons: Lower CPU usage.
  * Allow to not synchronise the server's external storages by
    default.
  * Switch to the new Nextcloud Server WebDAV endpoint.
  * Chunking NG: New file upload chunking algorithm for
    Nextcloud Server 11.0.
  * Allow to synchronise a directory to multiple different servers
    (filename change from .csync_journal.db to _sync_$HASH.db).
  * Conflicts: Use the local mtime for the conflict file name
    (gh#owncloud/client#5273).
  * Add a "Sync now" menu item.
  * Improve SSL Client certificate support (Show UI, Store keys in
    keychain).
  * Propagator: Upload smaller files in parallel.
  * Sync Engine: Read data-fingerprint property to detect backups
    (gh#owncloud/client#2325).
  * GUI: Show link to create an application password/token for
    synchronising.
  * Share dialogue: Add a "Mail link" button.
  * A Caja file manager plugin.
  * Make the "backup detected" message not triggered in wrong cases.
  * SyncEngine: Fix directory renaming when files are changed
    (gh#owncloud/client#5192)
  * Fix a reconnect bug if status.php intermittently returns wrong
    data (gh#owncloud/client#5188).
  * Improve synchronisation scheduling (gh#owncloud/client#5317).
  * Overlay icons: Improvements in correctnes.
  * Tray menu: Only update on demand to fix GNU/Linux desktop
    integration glitches.
  * Progress: Better time/bandwidth estimations.
  * Network: Follow certain HTTP redirects (gh#owncloud/client#2791).
  * Network: Remove all cookies (including load balancers, etc.)
    when logging out.
  * Discovery thread: Low priority.
  * nextcloudsync.log: Write during propagation.
  * Excludes: Consider files in hidden directories excluded
    (gh#owncloud/client#5163).
  * Allow the synchronised directory to be a symlinked directory.
  * Improve HTTP redirect handling (gh#owncloud/client#5555).
  * Blacklist: Escalate repeated soft error to normal error
    (gh#owncloud/client#5500).
  * Fix the URL for linking to application password generation for
    ownCloud 10.0 (gh#owncloud/client#5605).
  * Shibboleth bugfixes.
  * Fixes with regards to low disc space.
  * A tonne of other bugfixes.
  * Refactorings.
  * Improve documentation.
  * Crash fixes.
- Add nextcloud-client-remove-datetime.patch: Remove __TIME__ and
  __DATE__.
- Rebase and rename nextcloud-client-fix-nemo-appname.patch to
  nextcloud-client-fix-caja-nemo-appnames.patch.
- Remove nextcloud-client-fix-dolphin.patch,
  nextcloud-client-fix-ru-typo.patch,
  nextcloud-client-fix-tray-workaround.patch: fixed upstream.
- Rename 100-sync-inotify.conf to the less conflicting
  100-nextcloud-sync-inotify.conf.
* Fri Feb  3 2017 sor.alexei@meowr.ru
- Add nextcloud-client-fix-dolphin.patch from bruno_friedmann to
  fix the Dolphin plugin.
* Tue Jan 24 2017 sor.alexei@meowr.ru
- Add nextcloud-client-fix-tray-workaround.patch: fix the tray
  workaround (from commit 98efb07 of owncloud-client).
* Fri Sep 30 2016 ecsos@opensuse.org
- Update to version 2.2.4:
  * Dolphin Plugin: Use the Application name for the socket path
    (gh#owncloud/client#5172).
  * SyncEngine: Fix renaming of directories when files are changed
    (gh#owncloud/client#5195).
  * Selective Sync: Fix HTTP request loop and show error in view
    (gh#owncloud/client#5154).
  * ConnectionValidator: Properly handle error in status.php
    request (gh#owncloud/client#5188).
  * Discovery: Set thread priority to low (gh#owncloud/client#5017).
  * ExcludeFiles: Fix when the directory casing is not the same in
    the settings and in the FS.
  * ShareLink: Ensure the password line edit is enabled
    (gh#owncloud/client#5117).
* Fri Aug 26 2016 sor.alexei@meowr.ru
- Initial package.
